@@ -1,6 +1,11 @@
 
-init_oauth_service_account <- function(secrets, scope = NULL) {
-  signature <- jwt_signature(secrets, aud = secrets$token_uri, scope = scope)
+init_oauth_service_account <- function(secrets, scope = NULL, sub = NULL) {
+  signature <- jwt_signature(
+    secrets,
+    aud = secrets$token_uri,
+    scope = scope,
+    sub = sub
+  )
 
   res <- POST(
     secrets$token_uri,
@@ -18,11 +23,24 @@ init_oauth_service_account <- function(secrets, scope = NULL) {
 #' Generate a JWT signature given credentials.
 #'
 #' As described in
-#' \url{https://developers.google.com/accounts/docs/OAuth2ServiceAccount}
+#' <https://developers.google.com/identity/protocols/oauth2/service-account>
 #'
 #' @param credentials Parsed contents of the credentials file.
 #' @param scope A space-delimited list of the permissions that the application
 #'    requests.
+#' @param iss Email address of the client_id of the application making the
+#'   access token request.
+#' @param scope A space-delimited list of the permissions that the application
+#'    requests.
+#' @param sub The email address of the user for which the application is
+#'    requesting delegated access.
+#' @param aud A descriptor of the intended target of the assertion. This
+#'    typically comes from the service auth file.
+#' @param iat The time the assertion was issued, measured in seconds since
+#'    00:00:00 UTC, January 1, 1970.
+#' @param exp The expiration time of the assertion, measured in seconds since
+#'   00:00:00 UTC, January 1, 1970. This value has a maximum of 1 hour from
+#'   the issued time.
 #' @param duration Duration of token, in seconds.
 #' @keywords internal
 #' @examples
@@ -30,10 +48,22 @@ init_oauth_service_account <- function(secrets, scope = NULL) {
 #' cred <- jsonlite::fromJSON("~/Desktop/httrtest-45693cbfac92.json")
 #' jwt_signature(cred, "https://www.googleapis.com/auth/userinfo.profile")
 #' }
-jwt_signature <- function(credentials, scope, aud, duration = 60L * 60L) {
-  now <- as.integer(Sys.time())
-  cs <- jwt_claimset(credentials$client_email, scope, aud = aud, iat = now,
-    exp = now + duration)
+jwt_signature <- function(credentials,
+                          scope,
+                          aud,
+                          sub = NULL,
+                          iat = as.integer(Sys.time()),
+                          exp = iat + duration,
+                          duration = 60L * 60L) {
+  cs <- compact(list(
+    iss = credentials$client_email,
+    scope = scope,
+    aud = aud,
+    sub = sub,
+    iat = iat,
+    exp = exp
+  ))
+
   jwt_sign(cs, credentials$private_key)
 }
 
@@ -54,35 +84,6 @@ jwt_header <- function() {
   )
 }
 
-#' @param iss Email address of the client_id of the application making the
-#'   access token request.
-#' @param scope A space-delimited list of the permissions that the application
-#'    requests.
-#' @param aud A descriptor of the intended target of the assertion. This
-#'    typically comes from the service auth file.
-#' @param exp The expiration time of the assertion, measured in seconds since
-#'   00:00:00 UTC, January 1, 1970. This value has a maximum of 1 hour from
-#'   the issued time.
-#' @param iat The time the assertion was issued, measured in seconds since
-#'  00:00:00 UTC, January 1, 1970.
-#' @noRd
-jwt_claimset <- function(iss, scope, aud, exp = NULL, iat = NULL) {
-
-  if (is.null(iat)) {
-    iat <- as.integer(Sys.time())
-  }
-  if (is.null(exp)) {
-    exp <- iat + 60L * 60L
-  }
-
-  list(
-    iss = iss,
-    scope = scope,
-    aud = aud,
-    exp = exp,
-    iat = iat
-  )
-}
 
 jwt_base64 <- function(x) base64url(jwt_json(x))
 jwt_json <- function(x) jsonlite::toJSON(x, auto_unbox = TRUE)
@@ -90,6 +91,6 @@ base64url <- function(x) {
   if (is.character(x)) {
     x <- charToRaw(x)
   }
-  out <- chartr('+/', '-_', openssl::base64_encode(x))
+  out <- chartr("+/", "-_", openssl::base64_encode(x))
   gsub("=+$", "", out)
 }
